@@ -1,5 +1,7 @@
-#ifdef __GCC__
+#ifdef __GNUC__
+#ifndef alloca
 #define alloca __builtin_alloca
+#endif
 #else
 #ifdef __FreeBSD__
 #include <stdlib.h>
@@ -8,7 +10,7 @@
 #endif
 #endif
 
-#define NCC_VERSION "2.3"
+#define NCC_VERSION "2.5"
 #define GNU_VIOLATIONS
 #define LABEL_VALUES
 #define OUTPUT_EXT ".nccout"
